@@ -21,6 +21,7 @@
 #' @param rows Vector of row names.
 #' @param safe Do not throw error if for instance the variable to be
 #'   renamed/removed doesn't exist.
+#' @param verbose Toggle warnings and messages.
 #' @param ... Other arguments passed to or from other functions.
 #'
 #' @return A modified data frame.
@@ -36,20 +37,26 @@
 #' head(data_rename(iris, NULL))
 #'
 #' # Change all
-#' head(data_rename(iris, paste0("Var", 1:5)))
+#' head(data_rename(iris, replacement = paste0("Var", 1:5)))
 #'
 #' @seealso
 #' - Functions to rename stuff: [data_rename()], [data_rename_rows()], [data_addprefix()], [data_addsuffix()]
 #' - Functions to reorder or remove columns: [data_reorder()], [data_relocate()], [data_remove()]
 #' - Functions to reshape, pivot or rotate data frames: [data_to_long()], [data_to_wide()], [data_rotate()]
-#' - Functions to recode data: [rescale()], [reverse()], [categorize()], [recode_values()], [slide()]
+#' - Functions to recode data: [rescale()], [reverse()], [categorize()],
+#'   [recode_values()], [slide()]
 #' - Functions to standardize, normalize, rank-transform: [center()], [standardize()], [normalize()], [ranktransform()], [winsorize()]
 #' - Split and merge data frames: [data_partition()], [data_merge()]
-#' - Functions to find or select columns: [data_select()], [data_find()]
+#' - Functions to find or select columns: [data_select()], [extract_column_names()]
 #' - Functions to filter rows: [data_match()], [data_filter()]
 #'
 #' @export
-data_rename <- function(data, pattern = NULL, replacement = NULL, safe = TRUE, ...) {
+data_rename <- function(data,
+                        pattern = NULL,
+                        replacement = NULL,
+                        safe = TRUE,
+                        verbose = TRUE,
+                        ...) {
   # change all names if no pattern specified
   if (is.null(pattern)) {
     pattern <- names(data)
@@ -66,7 +73,7 @@ data_rename <- function(data, pattern = NULL, replacement = NULL, safe = TRUE, .
 
   # if duplicated names in replacement, append ".2", ".3", etc. to duplicates
   # ex: c("foo", "foo") -> c("foo", "foo.2")
-  if (any(duplicated(replacement))) {
+  if (anyDuplicated(replacement) > 0L) {
     dup <- as.data.frame(table(replacement))
     dup <- dup[dup$Freq > 1, ]
     for (i in dup$replacement) {
@@ -76,14 +83,14 @@ data_rename <- function(data, pattern = NULL, replacement = NULL, safe = TRUE, .
     }
   }
 
-  if (length(replacement) > length(pattern)) {
+  if (length(replacement) > length(pattern) && verbose) {
     insight::format_alert(
       paste0(
         "There are more names in `replacement` than in `pattern`. The last ",
         length(replacement) - length(pattern), " names of `replacement` are not used."
       )
     )
-  } else if (length(replacement) < length(pattern)) {
+  } else if (length(replacement) < length(pattern) && verbose) {
     insight::format_alert(
       paste0(
         "There are more names in `pattern` than in `replacement`. The last ",
@@ -94,7 +101,7 @@ data_rename <- function(data, pattern = NULL, replacement = NULL, safe = TRUE, .
 
   for (i in seq_along(pattern)) {
     if (!is.na(replacement[i])) {
-      data <- .data_rename(data, pattern[i], replacement[i], safe)
+      data <- .data_rename(data, pattern[i], replacement[i], safe, verbose)
     }
   }
 
@@ -102,9 +109,17 @@ data_rename <- function(data, pattern = NULL, replacement = NULL, safe = TRUE, .
 }
 
 #' @keywords internal
-.data_rename <- function(data, pattern, replacement, safe = TRUE) {
-  if (isFALSE(safe) && !pattern %in% names(data)) {
-    insight::format_error(paste0("Variable `", pattern, "` is not in your data frame :/"))
+.data_rename <- function(data, pattern, replacement, safe = TRUE, verbose = TRUE) {
+  if (!pattern %in% names(data)) {
+    if (isTRUE(safe)) {
+      # only give message when verbose is TRUE
+      if (verbose) {
+        insight::format_alert(paste0("Variable `", pattern, "` is not in your data frame :/"))
+      }
+      # if not safe, always error, no matter what verbose is
+    } else {
+      insight::format_error(paste0("Variable `", pattern, "` is not in your data frame :/"))
+    }
   }
 
   names(data) <- replace(names(data), names(data) == pattern, replacement)
