@@ -15,7 +15,7 @@
 #' factor levels are dropped from the frequency table.
 #' @param name Optional character string, which includes the name that is used
 #' for printing.
-#' @param include_na Logical, if `TRUE`, missing values are included in the
+#' @param remove_na Logical, if `FALSE`, missing values are included in the
 #' frequency or crosstable, else missing values are omitted.
 #' @param collapse Logical, if `TRUE` collapses multiple tables into one larger
 #' table for printing. This affects only printing, not the returned object.
@@ -28,12 +28,19 @@
 #' @param ... not used.
 #' @inheritParams extract_column_names
 #'
+#' @details
+#' There is an `as.data.frame()` method, to return the frequency tables as a
+#' data frame. The structure of the returned object is a nested data frame,
+#' where the first column contains name of the variable for which frequencies
+#' were calculated, and the second column is a list column that contains the
+#' frequency tables as data frame. See 'Examples'.
+#'
 #' @section Crosstables:
 #' If `by` is supplied, a crosstable is created. The crosstable includes `<NA>`
 #' (missing) values by default. The first column indicates values of `x`, the
 #' first row indicates values of `by` (including missing values). The last row
 #' and column contain the total frequencies for each row and column, respectively.
-#' Setting `include_na = FALSE` will omit missing values from the crosstable.
+#' Setting `remove_na = FALSE` will omit missing values from the crosstable.
 #' Setting `proportions` to `"row"` or `"column"` will add row or column
 #' percentages. Setting `proportions` to `"full"` will add relative frequencies
 #' for the full table.
@@ -55,7 +62,7 @@
 #' data_tabulate(efc$c172code)
 #'
 #' # drop missing values
-#' data_tabulate(efc$c172code, include_na = FALSE)
+#' data_tabulate(efc$c172code, remove_na = TRUE)
 #'
 #' # data frame
 #' data_tabulate(efc, c("e42dep", "c172code"))
@@ -102,12 +109,18 @@
 #'   efc$c172code,
 #'   by = efc$e16sex,
 #'   proportions = "column",
-#'   include_na = FALSE
+#'   remove_na = TRUE
 #' )
 #'
 #' # round percentages
 #' out <- data_tabulate(efc, "c172code", by = "e16sex", proportions = "column")
 #' print(out, digits = 0)
+#'
+#' # coerce to data frames
+#' result <- data_tabulate(efc, "c172code", by = "e16sex")
+#' as.data.frame(result)
+#' as.data.frame(result)$table
+#' as.data.frame(result, add_total = TRUE)$table
 #' @export
 data_tabulate <- function(x, ...) {
   UseMethod("data_tabulate")
@@ -120,7 +133,7 @@ data_tabulate.default <- function(x,
                                   by = NULL,
                                   drop_levels = FALSE,
                                   weights = NULL,
-                                  include_na = TRUE,
+                                  remove_na = FALSE,
                                   proportions = NULL,
                                   name = NULL,
                                   verbose = TRUE,
@@ -150,7 +163,7 @@ data_tabulate.default <- function(x,
       x,
       by = by,
       weights = weights,
-      include_na = include_na,
+      remove_na = remove_na,
       proportions = proportions,
       obj_name = obj_name,
       group_variable = group_variable
@@ -159,23 +172,16 @@ data_tabulate.default <- function(x,
 
   # frequency table
   if (is.null(weights)) {
-    if (include_na) {
-      freq_table <- tryCatch(table(addNA(x)), error = function(e) NULL)
-    } else {
+    if (remove_na) {
+      # we have a `.default` and a `.data.frame` method for `data_tabulate()`.
+      # since this is the default, `x` can be an object which cannot be used
+      # with `table()`, that's why we add `tryCatch()` here. Below we give an
+      # informative error message for non-supported objects.
       freq_table <- tryCatch(table(x), error = function(e) NULL)
+    } else {
+      freq_table <- tryCatch(table(addNA(x)), error = function(e) NULL)
     }
-  } else if (include_na) {
-    # weighted frequency table, including NA
-    freq_table <- tryCatch(
-      stats::xtabs(
-        weights ~ x,
-        data = data.frame(weights = weights, x = addNA(x)),
-        na.action = stats::na.pass,
-        addNA = TRUE
-      ),
-      error = function(e) NULL
-    )
-  } else {
+  } else if (remove_na) {
     # weighted frequency table, excluding NA
     freq_table <- tryCatch(
       stats::xtabs(
@@ -186,6 +192,17 @@ data_tabulate.default <- function(x,
       ),
       error = function(e) NULL
     )
+  } else {
+    # weighted frequency table, including NA
+    freq_table <- tryCatch(
+      stats::xtabs(
+        weights ~ x,
+        data = data.frame(weights = weights, x = addNA(x)),
+        na.action = stats::na.pass,
+        addNA = TRUE
+      ),
+      error = function(e) NULL
+    )
   }
 
   if (is.null(freq_table)) {
@@ -205,12 +222,12 @@ data_tabulate.default <- function(x,
 
   out$`Raw %` <- 100 * out$N / sum(out$N)
   # if we have missing values, we add a row with NA
-  if (include_na) {
-    out$`Valid %` <- c(100 * out$N[-nrow(out)] / sum(out$N[-nrow(out)]), NA)
-    valid_n <- sum(out$N[-length(out$N)], na.rm = TRUE)
-  } else {
+  if (remove_na) {
     out$`Valid %` <- 100 * out$N / sum(out$N)
     valid_n <- sum(out$N, na.rm = TRUE)
+  } else {
+    out$`Valid %` <- c(100 * out$N[-nrow(out)] / sum(out$N[-nrow(out)]), NA)
+    valid_n <- sum(out$N[-length(out$N)], na.rm = TRUE)
   }
   out$`Cumulative %` <- cumsum(out$`Valid %`)
 
@@ -242,7 +259,7 @@ data_tabulate.default <- function(x,
   attr(out, "total_n") <- sum(out$N, na.rm = TRUE)
   attr(out, "valid_n") <- valid_n
 
-  class(out) <- c("dw_data_tabulate", "data.frame")
+  class(out) <- c("datawizard_table", "data.frame")
 
   out
 }
@@ -258,7 +275,7 @@ data_tabulate.data.frame <- function(x,
                                      by = NULL,
                                      drop_levels = FALSE,
                                      weights = NULL,
-                                     include_na = TRUE,
+                                     remove_na = FALSE,
                                      proportions = NULL,
                                      collapse = FALSE,
                                      verbose = TRUE,
@@ -284,7 +301,7 @@ data_tabulate.data.frame <- function(x,
       proportions = proportions,
       drop_levels = drop_levels,
       weights = weights,
-      include_na = include_na,
+      remove_na = remove_na,
       name = i,
       verbose = verbose,
       ...
@@ -292,9 +309,9 @@ data_tabulate.data.frame <- function(x,
   })
 
   if (is.null(by)) {
-    class(out) <- c("dw_data_tabulates", "list")
+    class(out) <- c("datawizard_tables", "list")
   } else {
-    class(out) <- c("dw_data_xtabulates", "list")
+    class(out) <- c("datawizard_crosstabs", "list")
   }
   attr(out, "collapse") <- isTRUE(collapse)
   attr(out, "is_weighted") <- !is.null(weights)
@@ -313,11 +330,10 @@ data_tabulate.grouped_df <- function(x,
                                      proportions = NULL,
                                      drop_levels = FALSE,
                                      weights = NULL,
-                                     include_na = TRUE,
+                                     remove_na = FALSE,
                                      collapse = FALSE,
                                      verbose = TRUE,
                                      ...) {
-  # works only for dplyr >= 0.8.0
   grps <- attr(x, "groups", exact = TRUE)
   group_variables <- data_remove(grps, ".rows")
   grps <- grps[[".rows"]]
@@ -350,7 +366,7 @@ data_tabulate.grouped_df <- function(x,
       verbose = verbose,
       drop_levels = drop_levels,
       weights = weights,
-      include_na = include_na,
+      remove_na = remove_na,
       by = by,
       proportions = proportions,
       group_variable = group_variable,
@@ -358,9 +374,9 @@ data_tabulate.grouped_df <- function(x,
     ))
   }
   if (is.null(by)) {
-    class(out) <- c("dw_data_tabulates", "list")
+    class(out) <- c("datawizard_tables", "list")
   } else {
-    class(out) <- c("dw_data_xtabulates", "list")
+    class(out) <- c("datawizard_crosstabs", "list")
   }
   attr(out, "collapse") <- isTRUE(collapse)
   attr(out, "is_weighted") <- !is.null(weights)
@@ -381,8 +397,64 @@ insight::print_html
 insight::print_md
 
 
+#' @rdname data_tabulate
+#' @param add_total For crosstables (i.e. when `by` is not `NULL`), a row and
+#' column with the total N values are added to the data frame. `add_total` has
+#' no effect in `as.data.frame()` for simple frequency tables.
+#' @inheritParams base::as.data.frame
 #' @export
-format.dw_data_tabulate <- function(x, format = "text", big_mark = NULL, ...) {
+as.data.frame.datawizard_tables <- function(x,
+                                            row.names = NULL,
+                                            optional = FALSE,
+                                            ...,
+                                            stringsAsFactors = FALSE,
+                                            add_total = FALSE) {
+  # extract variables of frequencies
+  selected_vars <- unlist(lapply(x, function(i) attributes(i)$varname))
+  # coerce to data frame, remove rownames
+  data_frames <- lapply(x, function(i) {
+    # the `format()` methods for objects returned by `data_tabulate()` call
+    # `as.data.frame()` - we have to pay attention to avoid infinite iterations
+    # here. At the moment, this is no problem, as objects we have at this stage
+    # are of class "datawizard_table" or "datawizard_crosstab", while this
+    # `as.data.frame()` method is only called for "datawizard_tables" (the plural)
+    # form). Else, we would need to modify the class attribute here,
+    # e.g. class(i) <- "data.frame"
+    if (add_total) {
+      # to add the total column and row, we simply can call `format()`
+      out <- as.data.frame(format(i))
+      for (cols in 2:ncol(out)) {
+        # since "format()" returns a character matrix, we want to convert
+        # the columns to numeric. We have to exclude the first column, as the
+        # first column is character, due to the added "Total" value.
+        out[[cols]] <- as.numeric(out[[cols]])
+      }
+      # after formatting, we have a "separator" row for nicer printing.
+      # this should also be removed
+      out <- remove_empty_rows(out)
+    } else {
+      out <- as.data.frame(i)
+    }
+    rownames(out) <- NULL
+    out
+  })
+  # create nested data frame
+  result <- data.frame(
+    var = selected_vars,
+    table = I(data_frames),
+    stringsAsFactors = stringsAsFactors
+  )
+  # consider additional arguments
+  rownames(result) <- row.names
+  result
+}
+
+#' @export
+as.data.frame.datawizard_crosstabs <- as.data.frame.datawizard_tables
+
+
+#' @export
+format.datawizard_table <- function(x, format = "text", big_mark = NULL, ...) {
   # convert to character manually, else, for large numbers,
   # format_table() returns scientific notation
   x <- as.data.frame(x)
@@ -415,7 +487,7 @@ format.dw_data_tabulate <- function(x, format = "text", big_mark = NULL, ...) {
 
 
 #' @export
-print.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
+print.datawizard_table <- function(x, big_mark = NULL, ...) {
   a <- attributes(x)
 
   # "table" header with variable label/name, and type
@@ -457,7 +529,7 @@ print.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
 
 
 #' @export
-print_html.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
+print_html.datawizard_table <- function(x, big_mark = NULL, ...) {
   a <- attributes(x)
 
   # "table" header with variable label/name, and type
@@ -487,7 +559,7 @@ print_html.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
 
 
 #' @export
-print_md.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
+print_md.datawizard_table <- function(x, big_mark = NULL, ...) {
   a <- attributes(x)
 
   # "table" header with variable label/name, and type
@@ -517,7 +589,7 @@ print_md.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
 
 
 #' @export
-print.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
+print.datawizard_tables <- function(x, big_mark = NULL, ...) {
   # check if we have weights
   is_weighted <- isTRUE(attributes(x)$is_weighted)
 
@@ -556,7 +628,7 @@ print.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
 
 
 #' @export
-print_html.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
+print_html.datawizard_tables <- function(x, big_mark = NULL, ...) {
   # check if we have weights
   is_weighted <- isTRUE(attributes(x)$is_weighted)
 
@@ -585,7 +657,7 @@ print_html.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
 
 
 #' @export
-print_md.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
+print_md.datawizard_tables <- function(x, big_mark = NULL, ...) {
   # check if we have weights
   is_weighted <- isTRUE(attributes(x)$is_weighted)
 
